searchData={"items":[{"type":"module","title":"Enumx","doc":"","ref":"Enumx.html"},{"type":"function","title":"Enumx.all_equal?/1","doc":"Returns `true` if all elements in `enumerable` are equal.","ref":"Enumx.html#all_equal?/1"},{"type":"function","title":"Enumx.filter_value/2","doc":"Similar to filter/2, but returns the value of the function invocation instead of the element itself","ref":"Enumx.html#filter_value/2"},{"type":"function","title":"Enumx.unique_value!/1","doc":"Ensures that all elements in `enumerable` are equal, otherwise raises an error.\r\nIf all elements are equal, it returns one of those elements.","ref":"Enumx.html#unique_value!/1"},{"type":"extras","title":"Enumx","doc":"# Enumx\r\n\r\nAdditional utility functions to extend the power of Elixir's Enum module.\r\n\r\n## `filter_value/2`\r\n\r\nSimilar to `filter/2`, but returns the value of the function invocation instead of the element itself.\r\n\r\n```elixir\r\nassert Enumx.filter_value([1, 2, 3, 4, 5], &(&1 > 3 && &1 * 2)) == [8, 10]\r\n\r\nassert Enumx.filter_value([foo: 1, bar: 2, baz: 3], fn {k, v} -> v > 1 && k end) == [:bar, :baz]\r\n\r\nassert Enumx.filter_value(%{foo: 1, bar: 2, baz: 3}, fn {k, v} -> v > 1 && k end) == [:bar, :baz]\r\n```\r\n\r\n## `all_equal?/1`\r\n\r\nReturns `true` if all elements in `enumerable` are equal.\r\n\r\n```elixir\r\nassert Enumx.all_equal?([1, 1])\r\n\r\nassert Enumx.all_equal?([foo: 1, foo: 1])\r\n```\r\n\r\n## `unique_value!/1`\r\n\r\nReturns `true` if all elements in `enumerable` are equal.\r\n\r\n```elixir\r\nassert Enumx.unique_value!([1, 1]) == 1\r\n\r\nassert Enumx.unique_value!(%{foo: 1}) == {:foo, 1}\r\n\r\nassert Enumx.unique_value!([foo: 1, foo: 1]) == {:foo, 1}\r\n\r\nassert_raise ArgumentError, fn ->\r\n  Enumx.unique_value!([]) # raises error: cannot call `unique_value!/1` on an empty list\r\nend\r\n\r\nassert_raise RuntimeError, fn ->\r\n  Enumx.unique_value!([1, 2]) # raises error: elements in the list [1, 2] are not equal\r\nend\r\n```\r\n\r\n#","ref":"readme.html"},{"type":"extras","title":"Installation - Enumx","doc":"Add `enumx` for Elixir as a dependency in your `mix.exs` file:\r\n\r\n```elixir\r\ndef deps do\r\n  [\r\n    {:enumx, \"~> 0.2.0\"}\r\n  ]\r\nend\r\n```\r\n\r\n#","ref":"readme.html#installation"},{"type":"extras","title":"HexDocs - Enumx","doc":"HexDocs documentation can be found at [https://hexdocs.pm/enumx](https://hexdocs.pm/enumx).","ref":"readme.html#hexdocs"}],"content_type":"text/markdown"}